@@ -48,10 +48,10 @@ class Drive:
         def _upload(target: pathlib.Path, dest_dir: str) -> None:
             if target.is_file():
                 with target.open(mode='rb') as f:
-                    self.api.fs.upload_file(f, name=target.name, path=dest_dir)
+                    self.upload_file(f, name=target.name, path=dest_dir)
             elif target.is_dir():
                 try:
-                    self.api.fs.create_folder(name=target.name, path=dest_dir)
+                    self.create_folder(name=target.name, path=dest_dir)
                 except APIException as exc:
                     if 'Folder already exists' in exc.message:
                         pass
