@@ -45,7 +45,7 @@ class Project:
         return self.api.get(
             'project/nodes',
             params={'prjUUID': self.uuid},
-            headers={'sid': self.api.sid},
+            headers={'sid': self.api.sid} if self.api.sid else None,
         )['nodes']
 
     def get_execution_stats(self) -> List[Node]:
@@ -237,7 +237,7 @@ class Project:
         json = self.api.get(
             'project/nodes',
             params={'prjUUID': self.uuid},
-            headers={'sid': self.api.sid},
+            headers={'sid': self.api.sid} if self.api.sid else None,
         )
         return {node.pop('name'): node for node in json['nodes']}
 
@@ -325,7 +325,7 @@ class Parameters:
             strategies: Optional[List[int]] = None,
             declare_unsync: bool = True,
             hard_update: bool = True,
-    ) -> Optional[List[str]]:
+    ) -> None:
         """
         Sets `node_type` parameters and strategies for the Parameters node.
 
@@ -346,7 +346,7 @@ class Parameters:
 
         method = 'configure-array' if isinstance(parameters, list) else 'configure'
 
-        return self.api.post(
+        self.api.post(
             f'parameters/{method}',
             params={'prjUUID': self.uuid, 'obj': self.id},
             json={
@@ -395,6 +395,7 @@ class DataSet:
         # on purpose send wrong wrapperGuid(empty string) at first request to /dataset/* endpoints
         # to create dataset wrapper on server and retrieve its' guid by @retry_on_invalid_guid
         self.guid: str = ''
+        self._update_guid()  # temporary fix until server starts to return proper error response
 
     @retry_on_invalid_guid
     def get_info(self) -> Dict[str, Any]:
